==> CRTL-0.13.4-py3-none-any.whl: crtl/components/link_overrider.py <==
import json
from spacy.language import Language
from spacy.tokens import Doc

class LinkOverRider:
    def __init__(self,case_sensitive:bool):
        self._case_sensitive = case_sensitive
    def initialize(self, get_examples=None, nlp=None,path=None):
        self._load_json(path)
    def to_disk(self, path, exclude=tuple()):
        if not path.exists():
            path.mkdir()
        with open(path / "overrides_path.json","w+") as f:
            json.dump(self._original_dictionary,f)
    def _load_json(self,path):
        with open(path) as f:
            self._original_dictionary = json.load(f)
        if self._case_sensitive:
            self._overrides_dict = self._original_dictionary
        else:
            self._overrides_dict = {key.lower():value for key,value in self._original_dictionary.items()}
        return self
    def from_disk(self, path, exclude=tuple()):
        self._load_json(path / "overrides_path.json")
    def __call__(self, doc:Doc):
        overridden_ents = []
        for ent in doc.ents:
            # Overwrite the link there's an entry in the data
            if self._case_sensitive:
                ent_text = ent.text
            else:
                ent_text = ent.text.lower()
            if ent_text in self._overrides_dict:
                ent.kb_id_ = self._overrides_dict[ent_text]
            overridden_ents.append(ent)
        doc.set_ents(overridden_ents)
        return doc
    
@Language.factory(
    name="trend_literal_link_overrider",
    default_config={"case_sensitive": False},
)    
def make_ent_link_overrider(
    nlp: Language, name: str,case_sensitive:bool
    
):
    return LinkOverRider(case_sensitive)

==> CRTL-0.16.3-py3-none-any.whl: crtl/components/link_overrider.py <==
import json
from spacy.language import Language
from spacy.tokens import Doc


class LinkOverRider:
    def __init__(self, case_sensitive: bool):
        self._case_sensitive = case_sensitive

    def initialize(self, get_examples=None, nlp=None, path=None):
        self._load_json(path)

    def to_disk(self, path, exclude=tuple()):
        if not path.exists():
            path.mkdir()
        with open(path / "overrides_path.json", "w+") as f:
            json.dump(self._original_dictionary, f)

    def _load_json(self, path):
        with open(path) as f:
            self._original_dictionary = json.load(f)
        if self._case_sensitive:
            self._overrides_dict = self._original_dictionary
        else:
            self._overrides_dict = {
                key.lower(): value for key, value in self._original_dictionary.items()
            }
        return self

    def from_disk(self, path, exclude=tuple()):
        self._load_json(path / "overrides_path.json")

    def __call__(self, doc: Doc):
        overridden_ents = []
        for ent in doc.ents:
            # Overwrite the link there's an entry in the data
            if self._case_sensitive:
                ent_text = ent.text
            else:
                ent_text = ent.text.lower()
            if ent_text in self._overrides_dict:
                ent.kb_id_ = self._overrides_dict[ent_text]
            overridden_ents.append(ent)
        doc.set_ents(overridden_ents)
        return doc


@Language.factory(
    name="trend_literal_link_overrider",
    default_config={"case_sensitive": False},
)
def make_ent_link_overrider(nlp: Language, name: str, case_sensitive: bool):
    return LinkOverRider(case_sensitive)
